<?php

namespace App\Exports;

use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\FromView;
use Illuminate\Contracts\View\View;
use Illuminate\Support\Facades\DB;
use Maatwebsite\Excel\Concerns\ShouldAutoSize;
use PhpOffice\PhpSpreadsheet\Style\NumberFormat;
use Maatwebsite\Excel\Concerns\WithColumnFormatting;
use Carbon\Carbon;


class Rango implements FromView, WithColumnFormatting, ShouldAutoSize
{
    /**
    * @return \Illuminate\Support\Collection
    */

    public function __construct($id1, $id2, $id3, $id4){
        $this->id1 = $id1;
        $this->id2 = $id2;
        $this->id3 = $id3;
        $this->id4 = $id4;
    }

    public function columnFormats(): array
    {

        return ['L' => NumberFormat::FORMAT_NUMBER_00];

    }

    public function view(): View{
        $mytime = Carbon::now('America/Lima');
        $fecha = $mytime->toDateString();
        $fecha_hora = $mytime->toDateTimeString();
        $start = Carbon::now()->startOfYear()->toDateString();

        $id1 = empty($this->id1) ? $start : $this->id1;
        $id2 = empty($this->id2) ? $fecha : $this->id2;

        $id3 = $this->id3 == 'TODO' ? '' : $this->id3;
        $id4 = $this->id4== 'TODO' ? '' : $this->id4;
        $id4 = auth()->user()->tipo == 'DOCTOR' ? auth()->user()->nombres: $id4;

        $cita = DB::table('cita as c')
        ->join('usuario as u', 'c.codUsuario','=', 'u.CodUsuario')
        ->join('paciente as p', 'c.codPaciente','=', 'p.codPaciente')
        ->join('consultorio as co', 'u.codConsultorio', 'co.codConsultorio')
        ->select('codCita', 'asunto', 'fechaCita', 'horaCita', 'horaFinal', 'c.estado', 'fechCreacion', 'nomConsul',
        'u.nombres as nomUsuario', 'p.nombres as nomPaciente', 'diagnostico', 'costo')
        ->whereBetween('fechaCita', [$id1, $id2])
        ->where('u.nombres', 'LIKE', '%' . $id4 . '%')
        ->Where(function ($q)  use ($id3) {
            $q->orWhere('horaCita', 'LIKE', '%' . $id3 . '%')
                ->orWhere('horaFinal', 'LIKE', '%' . $id3 . '%')
                ->orWhere('nomConsul', 'LIKE', '%' . $id3 . '%')
                ->orWhere('p.nombres', 'LIKE', '%' . $id3 . '%')
                // ->orWhere('u.nombres', 'LIKE', '%' . $id3 . '%')
                ->orWhere('c.estado', 'LIKE', '%' . $id3 . '%');
        })
        ->orderByDesc('fechaCita')
        ->get();

        return view('reporte/rango.excel', ["id"=>$this->id1, "id2"=>$this->id2, "id3"=>$this->id3, "id4"=>$this->id4,
        "cita"=>$cita, "fecha"=>$fecha]);
    }
}
