<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Agenda;
use Carbon\Carbon;
use App\Paciente;
use App\Http\Requests\PacienteFormRequest;
use Illuminate\Support\Facades\Redirect;


class AgendaController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }
    public function index(Request $request){

        if($request){
            $query = trim($request->get('searchText'));

            $consultorio = DB::table('consultorio')
            ->where('nomConsul', '!=', 'SIN CONSULTORIO')
            ->get();

            $doctor = DB::table('usuario as u')
            ->join('consultorio as c', 'u.codConsultorio', 'c.codConsultorio')
            ->where('estado','ACTIVO')
            ->where('tipo','DOCTOR')
            ->orderBy('nomConsul')
            ->orderBy('nombres')
            ->get();

            $paciente = DB::table('paciente')
            ->where('estado','ACTIVO')
            ->orderByDesc('codPaciente')
            ->get();

            $empresa = DB::table('empresa')->first();

            return view('historial.cita.index',["consultorio"=>$consultorio, "doctor"=>$doctor, "paciente"=>$paciente, "empresa"=>$empresa, "searchText" => $query]);
        }
    }

    public function validarFecha($id, $doctor, $paciente, $fecha, $horaInicial, $horaFinal)
    {
        $mytime = Carbon::now('America/Lima');
        $fecha_actual = $mytime->toDateString();
        $hora_actual = $mytime->toTimeString();

        $agenda = Agenda::select("*")
            ->whereDate('fechaCita', '=', $fecha)
            ->where('codCita', '!=', $id)
            ->where('codUsuario', $doctor)
            ->Where(function ($q)  use ($horaInicial, $horaFinal) {
                $q->orwhereBetween('horaCita', [$horaInicial, $horaFinal])
                ->orWhereBetween('horaFinal', [$horaInicial, $horaFinal]);
            })
            ->first();


        if($agenda != null){ //El doctor ya tiene una cita
            $agenda = 2;
        }elseif(strtotime($fecha . $horaInicial) < strtotime($fecha_actual . $hora_actual)){ // las fechas son anteriores a la fecha actual
            $agenda = 1;
        }else{
            $agenda = Agenda::select("*")
            ->whereDate('fechaCita', $fecha)
            ->where('codCita', '!=', $id)
            ->where('codPaciente', $paciente)
            ->Where(function ($q)  use ($horaInicial, $horaFinal) {
                $q->orwhereBetween('horaCita', [$horaInicial, $horaFinal])
                ->orWhereBetween('horaFinal', [$horaInicial, $horaFinal]);
            })
            ->first();
             // El paciente tiene registrado otra cita en estas horas.
            $agenda = $agenda != null ? 3 : 0;
        }
        return $agenda;
        // return $agenda == null ? true : false;
    }


    public function guardar(Request $request){
        $input = $request->all();
        $val_registro = $this->validarFecha(-1, $input["ddlDoctor"], $input["ddlPacientes"], $input["txtFecha"], $input["txtHoraInicial"], $input["txtHoraFinal"]);
        if ($val_registro == 0) {
            $agenda = Agenda::create([
                "asunto" => $input["txtAsunto"],
                "codUsuario" => $input["ddlDoctor"],
                "codPaciente" => $input["ddlPacientes"],
                "fechaCita" => $input["txtFecha"],
                "horaCita" => $input["txtHoraInicial"],
                "horaFinal" => $input["txtHoraFinal"],
                "duracion" => $input["txtTiempo"],
                "estado"=> 'PENDIENTE',
                "indicaciones" => $input["txtIndicaciones"],
                "costo" => $input["txtCosto"]
            ]);
            // return response()->json(["ok" => true]);
            return response()->json(["ok" => 0]);
        } else {
            // return response()->json(["ok" => false]);
            return response()->json(["ok" => $val_registro]);
        }
    }

    public function editar(Request $request){
        $input = $request->all();
        $reg = DB::table('cita')->where('codCita', $input["id"])->first();
        $val_registro = $this->validarFecha($input["id"], $reg->codUsuario, $reg->codPaciente, $input["txtFecha"], $input["txtHoraInicial"], $input["txtHoraFinal"]);
        if ($val_registro == 0) {
            $agenda = Agenda::findOrFail($input["id"]);
            $agenda->fechaCita = $input["txtFecha"];
            $agenda->horaCita = $input["txtHoraInicial"];
            $agenda->horaFinal = $input["txtHoraFinal"];
            $agenda->update();
            return response()->json(["ok" => 0]);
        } else {
            return response()->json(["ok" => $val_registro]);
        }
    }

    public function editar2(Request $request){
        $input = $request->all();
        $reg_ant = DB::table('cita')->where('codCita', $input["id_e"])->first();
        $val_registro = $this->validarFecha($input["id_e"], $input["ddlDoctor_e"], $input["ddlPacientes_e"], $input["txtFecha_e"], $input["txtHoraInicial_e"], $input["txtHoraFinal_e"]);
        if ($reg_ant->fechaCita != $input["txtFecha_e"] || $reg_ant->horaCita != $input["txtHoraInicial_e"] || $reg_ant->horaFinal != $input["txtHoraFinal_e"]) {
            if ($val_registro == 0) {
                $agenda = Agenda::findOrFail($input["id_e"]);
                $agenda->asunto = $input["txtAsunto_e"];
                $agenda->codUsuario = $input["ddlDoctor_e"];
                $agenda->codPaciente = $input["ddlPacientes_e"];
                $agenda->fechaCita = $input["txtFecha_e"];
                $agenda->horaCita = $input["txtHoraInicial_e"];
                $agenda->horaFinal = $input["txtHoraFinal_e"];
                $agenda->duracion = $input["txtTiempo_e"];
                $agenda->indicaciones = $input["txtIndicaciones_e"];
                $agenda->costo = $input["txtCosto_e"];
                $agenda->update();
                return response()->json(["ok" => 0]);
            } else {
                return response()->json(["ok" => $val_registro]);
            }
        }else if ($reg_ant->codUsuario != $input["ddlDoctor_e"] || $reg_ant->codPaciente != $input["ddlPacientes_e"] ){
            if ($val_registro == 0) {
                $agenda = Agenda::findOrFail($input["id_e"]);
                $agenda->asunto = $input["txtAsunto_e"];
                $agenda->codUsuario = $input["ddlDoctor_e"];
                $agenda->codPaciente = $input["ddlPacientes_e"];
                $agenda->fechaCita = $input["txtFecha_e"];
                $agenda->horaCita = $input["txtHoraInicial_e"];
                $agenda->horaFinal = $input["txtHoraFinal_e"];
                $agenda->duracion = $input["txtTiempo_e"];
                $agenda->indicaciones = $input["txtIndicaciones_e"];
                $agenda->costo = $input["txtCosto_e"];
                $agenda->update();
                return response()->json(["ok" => 0]);
            } else {
                return response()->json(["ok" => $val_registro]);
            }
        }else{
            $agenda = Agenda::findOrFail($input["id_e"]);
            $agenda->asunto = $input["txtAsunto_e"];
            $agenda->codUsuario = $input["ddlDoctor_e"];
            $agenda->codPaciente = $input["ddlPacientes_e"];
            $agenda->fechaCita = $input["txtFecha_e"];
            $agenda->horaCita = $input["txtHoraInicial_e"];
            $agenda->horaFinal = $input["txtHoraFinal_e"];
            $agenda->duracion = $input["txtTiempo_e"];
            $agenda->indicaciones = $input["txtIndicaciones_e"];
            $agenda->costo = $input["txtCosto_e"];
            $agenda->update();
            return response()->json(["ok" => 0]);
        }

    }



    public function listar($id)
    {
        // $agenda = Agenda::all();
        if (auth()->user()->tipo == 'DOCTOR') {
            $agenda = DB::table('cita as c')
                ->join('usuario as u', 'c.codUsuario','=', 'u.CodUsuario')
                ->join('paciente as p', 'c.codPaciente','=', 'p.codPaciente')
                ->join('consultorio as co', 'u.codConsultorio','=', 'co.codConsultorio')
                ->select('codCita', 'fechaCita', 'horaCita', 'horaFinal', 'c.estado', 'fechCreacion', 'indicaciones', 'duracion', 'asunto',
                'u.nombres as nomUsuario', 'p.nombres as nomPaciente', 'nomConsul', 'c.codPaciente', 'co.codConsultorio', 'u.codUsuario', 'costo')
                ->where('c.codUsuario', auth()->user()->codUsuario)
                ->get();
        }else if($id != -1){
            $agenda = DB::table('cita as c')
            ->join('usuario as u', 'c.codUsuario','=', 'u.CodUsuario')
            ->join('paciente as p', 'c.codPaciente','=', 'p.codPaciente')
            ->join('consultorio as co', 'u.codConsultorio','=', 'co.codConsultorio')
            ->select('codCita', 'fechaCita', 'horaCita', 'horaFinal', 'c.estado', 'fechCreacion', 'indicaciones', 'duracion', 'asunto',
            'u.nombres as nomUsuario', 'p.nombres as nomPaciente', 'nomConsul', 'c.codPaciente', 'co.codConsultorio', 'u.codUsuario', 'costo')
            ->where('c.codUsuario', $id)
            ->get();
        }else{
            $agenda = DB::table('cita as c')
            ->join('usuario as u', 'c.codUsuario','=', 'u.CodUsuario')
            ->join('paciente as p', 'c.codPaciente','=', 'p.codPaciente')
            ->join('consultorio as co', 'u.codConsultorio','=', 'co.codConsultorio')
            ->select('codCita', 'fechaCita', 'horaCita', 'horaFinal', 'c.estado', 'fechCreacion', 'indicaciones', 'duracion', 'asunto',
            'u.nombres as nomUsuario', 'p.nombres as nomPaciente', 'nomConsul', 'c.codPaciente', 'co.codConsultorio', 'u.codUsuario', 'costo')
            ->get();
        }

        $nueva_agenda = [];
        foreach ($agenda as $value) {
            $nueva_agenda[] = [
                "id" => $value->codCita,
                "start" => $value->fechaCita ." ". $value->horaCita,
                "end" => $value->fechaCita ." ". $value->horaFinal,
                "title" => $value->nomConsul . " - " . $value->nomUsuario,
                "backgroundColor" => $value->estado == 'PENDIENTE' ? "#17a2b8" : "#F86569",
                "textColor" => "#fff",
                "extendedProps" => [
                "asunto"=>$value->asunto,
                "codPaciente"=>$value->codPaciente,
                "codConsultorio"=>$value->codConsultorio,
                "codUsuario"=>$value->codUsuario,
                "indicaciones"=>$value->indicaciones,
                "tiempo"=>$value->duracion,
                "estado"=>$value->estado,
                "costo"=>$value->costo,
                ]
            ];
        }
        return response()->json($nueva_agenda);
    }

    public function ajax_consultorio(Request $request){
        if (auth()->user()->tipo == 'DOCTOR') {
            $usuario = DB::table('usuario')->where('codConsultorio', '=', $request->get('mensaje'))
            ->where('codUsuario', auth()->user()->codUsuario)
            ->get();

        }else{
            $usuario = DB::table('usuario')->where('codConsultorio', '=', $request->get('mensaje'))->get();
        }

        $cadena = "<div class='form-group'><label> Doctor </label><select id='ddlDoctor' name='ddlDoctor' class='form-control'>";
        foreach ($usuario as $item) {
            $cadena = $cadena . '<option value=' . $item->codUsuario . '>' . $item->nombres . '</option>';
        }
        echo $cadena . "</select></div>";
    }

    public function ajax_consultorio2(Request $request){
        if (auth()->user()->tipo == 'DOCTOR') {
            $usuario = DB::table('usuario')->where('codConsultorio', '=', $request->get('mensaje'))
            ->where('codUsuario', auth()->user()->codUsuario)
            ->get();
        }else{
            $usuario = DB::table('usuario')->where('codConsultorio', '=', $request->get('mensaje'))->get();
        }
        $cadena = "<div class='form-group'><label> Doctor </label><select id='ddlDoctor_e' name='ddlDoctor_e' class='form-control'>";
        foreach ($usuario as $item) {
            $cadena = $cadena . '<option value=' . $item->codUsuario . '>' . $item->nombres . '</option>';
        }
        echo $cadena . "</select></div>";
    }



}


