<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\DB;
use App\Http\Requests\CitaFormRequest;
use App\Agenda;
use Carbon\Carbon;


class CitaController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
        // $this->middleware('auth:webpaciente');

    }

    public function index(Request $request)
    {
        $mytime = Carbon::now('America/Lima');
        $fecha = $mytime->toDateString();
        $query = trim($request->get('searchText'));
        $query2 = trim($request->get('searchText2'));
        $query3 = trim($request->get('searchText3'));
        $query4 = trim($request->get('searchText4'));

        $query = empty($query) ? date('Y-m-01', strtotime($fecha)) : $query;
        $query2 = empty($query2) ? date('Y-m-t', strtotime($fecha)) : $query2;
        $query3 = $query3 == 'TODO' ? '': $query3;
        $query4 = $query4 == 'TODO' ? '': $query4;
        $query4 = auth()->user()->tipo == 'DOCTOR' ? auth()->user()->nombres: $query4;
        if ($request) {
            $cita = DB::table('cita as c')
                ->join('usuario as u', 'c.codUsuario','=', 'u.CodUsuario')
                ->join('consultorio as con', 'u.codConsultorio','=', 'con.codConsultorio')
                ->join('paciente as p', 'c.codPaciente','=', 'p.codPaciente')
                ->select('codCita', 'asunto', 'fechaCita', 'horaCita', 'horaFinal', 'c.estado', 'fechCreacion', 'nomConsul',
                'u.nombres as nomUsuario', 'p.nombres as nomPaciente', 'costo')
                ->orderByDesc('fechaCita')
                ->orderByDesc('horaCita')
                ->whereBetween('fechaCita', [$query, $query2])
                ->where('u.nombres', 'LIKE', '%' . $query4 . '%')
                ->Where(function ($q)  use ($query3) {
                    $q->orwhere('p.nombres', 'LIKE', '%' . $query3 . '%')
                    ->orwhere('horaCita', 'LIKE', '%' . $query3 . '%')
                    ->orwhere('horaFinal', 'LIKE', '%' . $query3 . '%')
                    ->orwhere('c.estado', 'LIKE', '%' . $query3 . '%')
                    ->orwhere('nomConsul', 'LIKE', '%' . $query3 . '%');
                })
                ->paginate(10);

            $query3 = empty($query3) ? 'TODO': $query3;
            $query4 = empty($query4) ? 'TODO': $query4;

            $doctor = DB::table('usuario as u')
                ->join('consultorio as c', 'u.codConsultorio', 'c.codConsultorio')
                ->where('tipo', 'DOCTOR')->get();

            return view('historial.listado-cita.index', ["cita" => $cita, "fecha" => $fecha, "doctor"=>$doctor,
             "searchText" => $query, "searchText2" => $query2, "searchText3" => $query3, "searchText4" => $query4]);
        }
    }


    public function show($id)
    {
        // obtenemos el id y el diagnostico separado por guiones
        // $n_id = explode('_', substr($id, 1));
        // echo $n_id[0] . ' ' . $n_id[1];
        // $cita = DB::table('cita')
        //     ->where('codCita', '=', $n_id[0])
        //     ->first();
        // if (isset($cita->estado)) {
        //     if ($cita->estado == 'PENDIENTE') {
        //         $estado = "CULMINADO";
        //     }
        // }
        // $cita2 = Agenda::findOrFail($n_id[0]);
        // $cita2->estado = $estado;
        // $cita2->diagnostico = $n_id[1];
        // $cita2->update();
        // return Redirect::to('historial/listado-cita');
        $cita = DB::table('cita as c')
            ->join('usuario as u', 'c.codUsuario','=', 'u.CodUsuario')
            ->join('consultorio as con', 'u.codConsultorio','=', 'con.codConsultorio')
            ->join('paciente as p', 'c.codPaciente','=', 'p.codPaciente')
            ->select('codCita', 'asunto', 'fechaCita', 'horaCita', 'horaFinal', 'c.estado', 'fechCreacion', 'nomConsul',
                'u.nombres as nomUsuario', 'p.nombres as nomPaciente', 'p.codPaciente', 'u.codUsuario',
                'c.costo')
            ->where('codCita', $id)->first();
        $triaje = DB::table('triaje as t')
            ->join('paciente as p', 't.codPaciente', 'p.codPaciente')
            ->join('usuario as u', 't.codUsuario', 'u.codUsuario')
            ->select('codTriaje', 'fechaTriaje', 'horaTriaje', 'p.codPaciente', 'p.nombres as nomPaciente', 'u.nombres as nomUsuario',
            'p.numDocumento', 'p.fechaNac', 'fechaTriaje', 'horaTriaje', 'precionArterial', 'temperatura', 'fRespiratoria',
            'fCardiaca', 'saturacion', 'peso', 'talla', 'imc', 'estadoFisico')
            ->where('t.codPaciente', $cita->codPaciente)->orderByDesc('codTriaje')->first();
        $paciente = DB::table('paciente')->where('codPaciente', $cita->codPaciente)->first();
        return view('historial.listado-cita.show', ["cita" => $cita,  "triaje"=>$triaje, "paciente"=>$paciente]);
    }

    public function culminaratencion(Request $request){
        $mytime = Carbon::now('America/Lima');
        $fecha = $mytime->toDateTimeString();
        $cita = Agenda::findOrFail($request->get('codCita'));
        $cita->asunto = $request->get('asunto');
        $cita->citaFinal = $fecha;
        $cita->examenFisico = $request->get('examenFisico');
        $cita->diagnostico = $request->get('diagnostico');
        $cita->tratamiento = $request->get('tratamiento');
        $cita->receta = $request->get('receta');
        $cita->costo = $request->get('costo');
        $cita->estado = 'CULMINADO';
        $cita->update();
        return Redirect::to('historial/listado-cita')->with(['success' => 'Cita concluida']);
    }

    public function destroy(Request $request, $id)
    {
        try {
            if ($request->ajax()) {

                $docu   = Agenda::findOrFail($id);

                if ($docu->delete()) {
                    return response()->json([
                        'success' => true,
                        'message' => '¡Satisfactorio!, Registro eliminado con éxito.',
                    ]);
                } else {
                    return response()->json([
                        'success' => false,
                        'message' => '¡Error!, No se pudo eliminar.',
                    ]);
                }
            }
        } catch (\Exception $e) {
            if ($request->ajax()) {
                return response()->json([
                    'success' => false,
                    'message' => '¡Error!, Este registro tiene enlazado uno o mas registros.',
                ]);
            }
        }
    }

    public function reportPdf($id)
    {
        $mytime = Carbon::now('America/Lima');
        $fecha = $mytime->toDateString();
        $hora = $mytime->toTimeString();

        $cita = DB::table('cita as c')
        ->join('usuario as u', 'c.codUsuario','=', 'u.CodUsuario')
        ->join('paciente as p', 'c.codPaciente','=', 'p.codPaciente')
        ->join('consultorio as co', 'u.codConsultorio','=', 'co.codConsultorio')
        ->select('codCita', 'asunto', 'fechaCita', 'horaCita', 'horaFinal', 'c.estado', 'fechCreacion', 'indicaciones', 'diagnostico',
                'u.nombres as nomUsuario', 'p.nombres as nomPaciente', 'p.numDocumento', 'p.fechaNac', 'p.genero', 'examenFisico',
                'tratamiento', 'receta', 'citaFinal', 'nomConsul')
        ->where('codCita', $id)
        ->first();
        $empresa = DB::table('empresa')->first();
        $pdf = \PDF::loadView('historial/listado-cita.report', ["fecha"=>$fecha, "hora"=>$hora,
            "cita" => $cita, "empresa"=> $empresa]);
        // ->setPaper('a4', 'landscape');
        return $pdf->stream('CITA ' . $cita->codCita);
    }

    public function listPdf($id, $id2, $id3, $id4)
    {
        $mytime = Carbon::now('America/Lima');
        $fecha = $mytime->toDateString();
        $fecha_hora = $mytime->toDateTimeString();

        $id = empty($id) ? $fecha : $id;
        $id2 = empty($id2) ? date('Y-m-t', strtotime($fecha)) : $id2;
        $id3 = $id3 == 'TODO' ? '': $id3;
        $id4 = $id4 == 'TODO' ? '': $id4;

        $cita = DB::table('cita as c')
            ->join('usuario as u', 'c.codUsuario','=', 'u.CodUsuario')
            ->join('consultorio as con', 'u.codConsultorio','=', 'con.codConsultorio')
            ->join('paciente as p', 'c.codPaciente','=', 'p.codPaciente')
            ->select('codCita', 'asunto', 'fechaCita', 'horaCita', 'horaFinal', 'c.estado', 'fechCreacion',
            'u.nombres as nomUsuario', 'p.nombres as nomPaciente', 'diagnostico', 'nomConsul', 'costo')
            ->orderByDesc('fechaCita')
            ->orderByDesc('horaCita')
            ->whereBetween('fechaCita', [$id, $id2])
            ->where('u.nombres', 'LIKE', '%' . $id4 . '%')
            ->Where(function ($q)  use ($id3) {
                $q->orwhere('p.nombres', 'LIKE', '%' . $id3 . '%')
                ->orwhere('horaCita', 'LIKE', '%' . $id3 . '%')
                ->orwhere('horaFinal', 'LIKE', '%' . $id3 . '%')
                ->orwhere('c.estado', 'LIKE', '%' . $id3 . '%')
                ->orwhere('nomConsul', 'LIKE', '%' . $id3 . '%');
            })->get();

        $empresa = DB::table('empresa')->first();
        $pdf = \PDF::loadView('historial/listado-cita.list', ["cita" => $cita, "empresa"=> $empresa, "id"=>$id, "id3"=>$id3,
                "fecha_hora"=>$fecha_hora])
        ->setPaper('a4', 'landscape');
        return $pdf->stream();
    }


}
