<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Carbon\Carbon;

class HistoPacienteController extends Controller
{

    public function __construct()
    {
        $this->middleware('auth:webpaciente');
    }

    public function index(Request $request)
    {
        $mytime = Carbon::now('America/Lima');
        $fecha = $mytime->toDateString();
        $query = trim($request->get('searchText'));
        $query2 = trim($request->get('searchText2'));
        $query3 = trim($request->get('searchText3'));


        $query = empty($query) ? date('Y-m-01', strtotime($fecha)) : $query;
        $query2 = empty($query2) ? date('Y-m-t', strtotime($fecha)) : $query2;
        $query3 = $query3 == 'TODO' ? '': $query3;

        if ($request) {
            $cita = DB::table('cita as c')
                ->join('usuario as u', 'c.codUsuario','=', 'u.CodUsuario')
                ->join('consultorio as con', 'u.codConsultorio','=', 'con.codConsultorio')
                ->join('paciente as p', 'c.codPaciente','=', 'p.codPaciente')
                ->select('codCita', 'asunto', 'fechaCita', 'horaCita', 'horaFinal', 'c.estado', 'fechCreacion', 'nomConsul',
                'u.nombres as nomUsuario', 'p.nombres as nomPaciente', 'costo')
                ->orderByDesc('fechaCita')
                ->orderByDesc('horaCita')
                ->where('p.codPaciente', auth()->guard('webpaciente')->user()->codPaciente)
                ->whereBetween('fechaCita', [$query, $query2])
                ->Where(function ($q)  use ($query3) {
                    $q->orwhere('horaCita', 'LIKE', '%' . $query3 . '%')
                    ->orwhere('horaFinal', 'LIKE', '%' . $query3 . '%')
                    ->orwhere('c.estado', 'LIKE', '%' . $query3 . '%')
                    ->orwhere('u.nombres', 'LIKE', '%' . $query3 . '%')
                    ->orwhere('nomConsul', 'LIKE', '%' . $query3 . '%');
                })
                ->paginate(10);

            $query3 = empty($query3) ? 'TODO': $query3;

            $doctor = DB::table('usuario as u')
                ->join('consultorio as c', 'u.codConsultorio', 'c.codConsultorio')
                ->where('tipo', 'DOCTOR')->get();

            return view('opciones.historial.index', ["cita" => $cita, "fecha" => $fecha, "doctor"=>$doctor,
             "searchText" => $query, "searchText2" => $query2, "searchText3" => $query3]);
        }
    }

    public function reportPdf($id)
    {
        $mytime = Carbon::now('America/Lima');
        $fecha = $mytime->toDateString();
        $hora = $mytime->toTimeString();

        $cita = DB::table('cita as c')
        ->join('usuario as u', 'c.codUsuario','=', 'u.CodUsuario')
        ->join('paciente as p', 'c.codPaciente','=', 'p.codPaciente')
        ->join('consultorio as co', 'u.codConsultorio','=', 'co.codConsultorio')
        ->select('codCita', 'asunto', 'fechaCita', 'horaCita', 'horaFinal', 'c.estado', 'fechCreacion', 'indicaciones', 'diagnostico',
                'u.nombres as nomUsuario', 'p.nombres as nomPaciente', 'p.numDocumento', 'p.fechaNac', 'p.genero', 'examenFisico',
                'tratamiento', 'receta', 'citaFinal', 'nomConsul')
        ->where('codCita', $id)
        ->first();
        $empresa = DB::table('empresa')->first();
        $pdf = \PDF::loadView('historial/listado-cita.report', ["fecha"=>$fecha, "hora"=>$hora,
            "cita" => $cita, "empresa"=> $empresa]);
        // ->setPaper('a4', 'landscape');
        return $pdf->stream('CITA ' . $cita->codCita);
    }
}
