<?php

namespace App\Http\Controllers;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\DB;
use App\Http\Requests\CitaFormRequest;
use App\Agenda;
use Carbon\Carbon;
use Maatwebsite\Excel\Facades\Excel;
use App\Exports\Rango;


class ReporteRangoController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }
    public function index(Request $request)
    {
        $mytime = Carbon::now('America/Lima');
        $fecha = $mytime->toDateString();
        // $start = Carbon::now()->startOfYear()->toDateString();
        $start = date('Y-m-01', strtotime($fecha));
        $end = date('Y-m-t', strtotime($fecha));

        $doctor = DB::table('usuario as u')
            ->join('consultorio as c', 'u.codConsultorio', 'c.codConsultorio')
            ->where('tipo', 'DOCTOR')
            ->orderBy('nomConsul')
            ->get();

        if ($request) {
            $query = trim($request->get('searchText'));
            $query2 = trim($request->get('searchText2'));
            $query3 = trim($request->get('searchText3'));
            $query4 = trim($request->get('searchText4'));

            if(empty($query)){
                $query = $start;
            }
            if(empty($query2)){
                $query2 = $end;
            }
            $query3 = $query3 == 'TODO' ? '' : $query3;
            $query4 = $query4 == 'TODO' ? '' : $query4;
            $query4 = auth()->user()->tipo == 'DOCTOR' ? auth()->user()->nombres: $query4;

            $cita = DB::table('cita as c')
                ->join('usuario as u', 'c.codUsuario','=', 'u.CodUsuario')
                ->join('paciente as p', 'c.codPaciente','=', 'p.codPaciente')
                ->join('consultorio as co', 'u.codConsultorio', 'co.codConsultorio')
                ->select('codCita', 'asunto', 'fechaCita', 'horaCita', 'horaFinal', 'c.estado', 'fechCreacion', 'nomConsul',
                'u.nombres as nomUsuario', 'p.nombres as nomPaciente', 'costo')
                ->whereBetween('fechaCita', [$query, $query2])
                ->where('u.nombres', 'LIKE', '%' . $query4 . '%')
                ->Where(function ($q)  use ($query3) {
                    $q->orWhere('horaCita', 'LIKE', '%' . $query3 . '%')
                        ->orWhere('horaFinal', 'LIKE', '%' . $query3 . '%')
                        ->orWhere('nomConsul', 'LIKE', '%' . $query3 . '%')
                        ->orWhere('p.nombres', 'LIKE', '%' . $query3 . '%')
                        // ->orWhere('u.nombres', 'LIKE', '%' . $query3 . '%')
                        ->orWhere('c.estado', 'LIKE', '%' . $query3 . '%');
                })
                ->orderByDesc('fechaCita')
                ->paginate(10);
            return view('reporte.rango.index', ["cita" => $cita, "fecha" => $fecha, "doctor" => $doctor,
            "searchText" => $query, "searchText2" => $query2, "searchText3" => $query3, "searchText4" => $query4]);
        }
    }


    public function show($id)
    {
        // obtenemos el id y el diagnostico separado por guiones
        $n_id = explode('_', substr($id, 1));

        // echo $n_id[0] . ' ' . $n_id[1];
        $cita = DB::table('cita')
            ->where('codCita', '=', $n_id[0])
            ->first();
        if (isset($cita->estado)) {
            if ($cita->estado == 'PENDIENTE') {
                $estado = "CULMINADO";
            }
        }

        $cita2 = Agenda::findOrFail($n_id[0]);
        $cita2->estado = $estado;
        $cita2->diagnostico = $n_id[1];
        $cita2->update();
        return Redirect::to('reporte/rango');
    }

    public function destroy(Request $request, $id)
    {
        try {
            if ($request->ajax()) {

                $docu   = Agenda::findOrFail($id);

                if ($docu->delete()) {
                    return response()->json([
                        'success' => true,
                        'message' => '¡Satisfactorio!, Registro eliminado con éxito.',
                    ]);
                } else {
                    return response()->json([
                        'success' => false,
                        'message' => '¡Error!, No se pudo eliminar.',
                    ]);
                }
            }
        } catch (\Exception $e) {
            if ($request->ajax()) {
                return response()->json([
                    'success' => false,
                    'message' => '¡Error!, Este registro tiene enlazado uno o mas registros.',
                ]);
            }
        }
    }

    public function reportPdf($id, $id2, $id3, $id4)
    {
        $mytime = Carbon::now('America/Lima');
        $fecha = $mytime->toDateString();
        $fecha_hora = $mytime->toDateTimeString();
        $start = Carbon::now()->startOfYear()->toDateString();

        if(empty($id)){
            $id = $start;
        }
        if(empty($id2)){
            $id2 = $fecha;
        }

        $id3 = $id3 == 'TODO' ? '' : $id3;
        $id4 = $id4 == 'TODO' ? '' : $id4;
        $id4 = auth()->user()->tipo == 'DOCTOR' ? auth()->user()->nombres: $id4;

        $cita = DB::table('cita as c')
        ->join('usuario as u', 'c.codUsuario','=', 'u.CodUsuario')
        ->join('paciente as p', 'c.codPaciente','=', 'p.codPaciente')
        ->join('consultorio as co', 'u.codConsultorio', 'co.codConsultorio')
        ->select('codCita', 'asunto', 'fechaCita', 'horaCita', 'horaFinal', 'c.estado', 'fechCreacion', 'nomConsul',
        'u.nombres as nomUsuario', 'p.nombres as nomPaciente', 'costo')
        ->whereBetween('fechaCita', [$id, $id2])
        ->where('u.nombres', 'LIKE', '%' . $id4 . '%')
        ->Where(function ($q)  use ($id3) {
            $q->orWhere('horaCita', 'LIKE', '%' . $id3 . '%')
                ->orWhere('horaFinal', 'LIKE', '%' . $id3 . '%')
                ->orWhere('nomConsul', 'LIKE', '%' . $id3 . '%')
                ->orWhere('p.nombres', 'LIKE', '%' . $id3 . '%')
                // ->orWhere('u.nombres', 'LIKE', '%' . $id3 . '%')
                ->orWhere('c.estado', 'LIKE', '%' . $id3 . '%');
        })
        ->orderByDesc('fechaCita')
        ->get();
        $empresa = DB::table('empresa')->first();
        $pdf = \PDF::loadView('reporte/rango.report', ["cita" => $cita, "empresa"=> $empresa, "fecha_hora"=>$fecha_hora,
        "id"=>$id, "id2"=>$id2, "id3"=>$id3])
        ->setPaper('a4', 'landscape');
        return $pdf->stream();
    }

    public function reportExcel($id, $id2, $id3, $id4)
    {
        return Excel::download(new Rango($id, $id2, $id3, $id4), 'RegistroCitas.xlsx');
    }
}
