<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Http\Requests\TriajeFormRequest;
use App\Triaje;
use App\Paciente;
use Illuminate\Support\Carbon;
use Illuminate\Support\Facades\Redirect;

class TriajeController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function index(Request $request){
        $query=trim($request->get('searchText'));
        $query2=trim($request->get('searchText2'));
        $paciente = DB::table('paciente')->where('estado', 'ACTIVO')->get();
        if($request){
            if (empty($query)) {
                $triaje = DB::table('triaje as t')
                ->join('paciente as p', 't.codPaciente', 'p.codPaciente')
                ->join('usuario as u', 't.codUsuario', 'u.codUsuario')
                ->select('codTriaje', 'fechaTriaje', 'horaTriaje', 'p.numDocumento', 'p.nombres as nomPaciente', 'u.nombres as nomUsuario')
                ->orderByDesc('fechaTriaje')
                ->orderByDesc('horaTriaje')
                ->paginate(10);
            }else{
                $triaje = DB::table('triaje as t')
                ->join('paciente as p', 't.codPaciente', 'p.codPaciente')
                ->join('usuario as u', 't.codUsuario', 'u.codUsuario')
                ->select('codTriaje', 'fechaTriaje', 'horaTriaje', 'p.numDocumento', 'p.nombres as nomPaciente', 'u.nombres as nomUsuario')
                ->orderByDesc('fechaTriaje')
                ->orderByDesc('horaTriaje')
                ->where('t.codPaciente', $query)
                ->paginate(10);
            }

             return view('historial.triaje.index',["triaje"=>$triaje, "paciente"=>$paciente, "searchText"=>$query, "searchText2"=>$query2]);
        }
    }

    public function create(Request $request)
    {
        if($request){
            $mytime = Carbon::now('America/Lima');
            $fecha = $mytime->toDateString();
            $hora = $mytime->toTimeString();
            $query=trim($request->get('searchText'));
            return view('historial.triaje.create', ["searchText"=>$query, "paciente" => Paciente::findOrFail($query), "fecha"=>$fecha, "hora"=>$hora]);
        }
    }

    public function store(TriajeFormRequest $request)
    {
        $mytime = Carbon::now('America/Lima');
        $fecha = $mytime->toDateString();
        $hora = $mytime->toTimeString();
        $triaje = new Triaje;
        $triaje->fechaTriaje = $fecha;
        $triaje->horaTriaje = $hora;
        $triaje->precionArterial = $request->get('precionArterial');
        $triaje->temperatura = $request->get('temperatura');
        $triaje->fRespiratoria = $request->get('fRespiratoria');
        $triaje->fCardiaca = $request->get('fCardiaca');
        $triaje->saturacion = $request->get('saturacion');
        $triaje->peso = $request->get('peso');
        $triaje->talla = $request->get('talla');
        $triaje->imc = $request->get('imc');
        $triaje->estadoFisico = $request->get('estadoFisico');
        $triaje->codPaciente = $request->get('codPaciente');
        $triaje->codUsuario = $request->get('codUsuario');
        $triaje->save();
        $paciente = DB::table('paciente')->where('codPaciente', $request->get('codPaciente'))->first();
        return Redirect::to('historial/triaje?searchText=' . $request->get('codPaciente'))->with(['success' => 'Se agregó un nuevo registro de información de ' . $paciente->nombres . '.']);
    }

    public function edit($id)
    {
        $triaje = DB::table('triaje as t')
            ->join('paciente as p', 't.codPaciente', 'p.codPaciente')
            ->join('usuario as u', 't.codUsuario', 'u.codUsuario')
            ->select('codTriaje', 'fechaTriaje', 'horaTriaje', 'p.codPaciente', 'p.nombres as nomPaciente', 'u.nombres as nomUsuario',
            'p.numDocumento', 'p.fechaNac', 'fechaTriaje', 'horaTriaje', 'precionArterial', 'temperatura', 'fRespiratoria',
            'fCardiaca', 'saturacion', 'peso', 'talla', 'imc', 'estadoFisico')
            ->where('codTriaje', $id)
            ->first();
        $mytime = Carbon::now('America/Lima');
        $fecha = $mytime->toDateString();
        $hora = $mytime->toTimeString();
        return view("historial.triaje.edit", ["triaje" => $triaje, "fecha"=>$fecha, "hora"=>$hora, "id"=>$id]);
    }

    public function update(TriajeFormRequest $request, $id)
    {
        $mytime = Carbon::now('America/Lima');
        $fecha = $mytime->toDateString();
        $hora = $mytime->toTimeString();
        $triaje = Triaje::findOrFail($id);
        $triaje->fechaTriaje = $fecha;
        $triaje->horaTriaje = $hora;
        $triaje->precionArterial = $request->get('precionArterial');
        $triaje->temperatura = $request->get('temperatura');
        $triaje->fRespiratoria = $request->get('fRespiratoria');
        $triaje->fCardiaca = $request->get('fCardiaca');
        $triaje->saturacion = $request->get('saturacion');
        $triaje->peso = $request->get('peso');
        $triaje->talla = $request->get('talla');
        $triaje->imc = $request->get('imc');
        $triaje->estadoFisico = $request->get('estadoFisico');
        $triaje->codPaciente = $request->get('codPaciente');
        $triaje->codUsuario = $request->get('codUsuario');
        $triaje->update();
        $paciente = DB::table('paciente')->where('codPaciente', $request->get('codPaciente'))->first();
        return Redirect::to('historial/triaje?searchText=' . $request->get('codPaciente'))->with(['success' => 'Se modificaron los datos del registro de información de ' . $paciente->nombres . '.']);
    }

    public function show( $id)
    {
        $triaje = DB::table('triaje as t')
            ->join('paciente as p', 't.codPaciente', 'p.codPaciente')
            ->join('usuario as u', 't.codUsuario', 'u.codUsuario')
            ->select('codTriaje', 'fechaTriaje', 'horaTriaje', 'p.codPaciente', 'p.nombres as nomPaciente', 'u.nombres as nomUsuario',
            'p.numDocumento', 'p.fechaNac', 'fechaTriaje', 'horaTriaje', 'precionArterial', 'temperatura', 'fRespiratoria',
            'fCardiaca', 'saturacion', 'peso', 'talla', 'imc', 'estadoFisico')
            ->where('codTriaje', $id)
            ->first();
        $mytime = Carbon::now('America/Lima');
        $fecha = $mytime->toDateString();
        $hora = $mytime->toTimeString();
        return view("historial.triaje.show", ["triaje" => $triaje, "fecha"=>$fecha, "hora"=>$hora, "id"=>$id]);
    }

}
