<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Http\Requests\UsuarioFormRequest;
use App\Http\Requests\UsuarioEditFormRequest;
use App\User;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Carbon;

class UsuarioController extends Controller
{
    public function __construct()
    {
        $this->middleware('auth');
    }
    public function index(Request $request)
    {
        if (auth()->user()->tipo != "ADMINISTRADOR" && auth()->user()->tipo != "SECRETARIA") {
            Auth::logout();
            return redirect('/')
                ->with('flash', 'Usted no tiene privilegios para ingresar en la ruta solicitada.');
        }
        $query = trim($request->get('searchText'));

        $query = $query == 'TODO'? '': $query;

        if ($request) {

            $tipos = ['ADMINISTRADOR', 'DOCTOR', 'SECRETARIA'];

            $sin_especialidad = DB::table('consultorio')
                ->where('nomConsul', '=', 'SIN CONSULTORIO')
                ->first();


            if (auth()->user()->tipo == 'SECRETARIA') {
                $consultorio = DB::table('consultorio')->where('nomConsul', '!=', 'SIN CONSULTORIO')->get();

                $usuario = DB::table('usuario as u')
                    ->join('consultorio as e', 'u.codConsultorio', '=', 'e.codConsultorio')
                    ->where('tipo', '=', 'DOCTOR')
                    ->Where(function ($q)  use ($query) {
                        $q->orWhere('nombres', 'LIKE', '%' . $query . '%')
                            ->orWhere('numDocumento', 'LIKE', '%' . $query . '%')
                            ->orWhere('estado', 'LIKE', '%' . $query . '%')
                            ->orWhere('direccion', 'LIKE', '%' . $query . '%')
                            ->orWhere('email', 'LIKE', '%' . $query . '%')
                            ->orWhere('telefono', 'LIKE', '%' . $query . '%')
                            ->orWhere('nomConsul', 'LIKE', '%' . $query . '%');
                    })
                    ->orderBy('nombres')
                    ->paginate(8);
            } else {
                $consultorio = DB::table('consultorio')
                ->where('nomConsul', '!=', 'SIN CONSULTORIO')
                ->get();

                $usuario = DB::table('usuario as u')
                    ->join('consultorio as e', 'u.codConsultorio', '=', 'e.codConsultorio')
                    ->orWhere('nombres', 'LIKE', '%' . $query . '%')
                    ->orWhere('numDocumento', 'LIKE', '%' . $query . '%')
                    ->orWhere('estado', 'LIKE', '%' . $query . '%')
                    ->orWhere('direccion', 'LIKE', '%' . $query . '%')
                    ->orWhere('email', 'LIKE', '%' . $query . '%')
                    ->orWhere('telefono', 'LIKE', '%' . $query . '%')
                    ->orWhere('tipo', 'LIKE', '%' . $query . '%')
                    ->orWhere('nomConsul', 'LIKE', '%' . $query . '%')
                    ->orderBy('nombres')
                    ->paginate(8);
            }
            $query = empty($query) ? 'TODO': $query;


            return view('acceso.usuario.index', ["tipos" => $tipos, "consultorio" => $consultorio, "sin_especialidad" => $sin_especialidad,
                "usuario" => $usuario, "searchText" => $query
            ]);
        }
    }

    public function store(UsuarioFormRequest $request)
    {
        $usuario = new User;
        $usuario->nombres = strtoupper($request->get('nombres'));
        // $usuario->Apellidos = $request->get('Apellidos');
        $usuario->numDocumento = $request->get('numDocumento');
        $usuario->password = bcrypt($request->get('numDocumento'));
        $usuario->direccion = $request->get('direccion');
        $usuario->telefono = $request->get('telefono');
        $usuario->email = $request->get('email');
        $usuario->estado = "ACTIVO";
        $usuario->tipo = $request->get('tipo');
        if ($request->hasFile('foto')) {
            $file = $request->file('foto');
            $file->move(public_path() . '/Imagen', $file->getClientOriginalName());
            $usuario->foto = $file->getClientOriginalName();
        }
        $usuario->codConsultorio = $request->get('tipo') != 'DOCTOR' ? '2' : $request->get('codConsultorio');
        $usuario->save();

        return Redirect::to('acceso/usuario')->with(['success' => 'Se agregó el usuario ' . $usuario->nombres .'.']);
    }


    public function edit($id)
    {
        $tipos = ['ADMINISTRADOR', 'DOCTOR', 'SECRETARIA'];
        $consultorio = DB::table('consultorio')
            ->where('nomConsul', '!=', 'SIN CONSULTORIO')
            ->get();
        $sin_especialidad = DB::table('consultorio')
            ->where('nomConsul', '=', 'SIN CONSULTORIO')
            ->first();
        return view("acceso.usuario.edit", ["usuario" => User::findOrFail($id), "tipos" => $tipos,
        "consultorio" => $consultorio, "sin_especialidad" => $sin_especialidad]);
    }



    public function update(UsuarioFormRequest $request, $id)
    {
        $usuario = User::findOrFail($id);
        $usuario->nombres = strtoupper($request->get('nombres'));
        // $usuario->Apellidos=$request->get('Apellidos');
        $usuario->numDocumento = $request->get('numDocumento');
        $usuario->direccion = $request->get('direccion');
        $usuario->telefono = $request->get('telefono');
        $usuario->email = $request->get('email');
        $usuario->tipo = $request->get('tipo');
        if ($request->get('password') != '') {
            $usuario->password = bcrypt($request->get('password'));
        }
        if ($request->hasFile('foto')) {
            $file = $request->file('foto');
            $file->move(public_path() . '/Imagen', $file->getClientOriginalName());
            $usuario->foto = $file->getClientOriginalName();
        }
        $usuario->codConsultorio = $request->get('tipo') != 'DOCTOR' ? '2' : $request->get('codConsultorio');
        $usuario->update();
        return Redirect::to('acceso/usuario')->with(['success' => 'Se modificaron los datos de ' . $usuario->nombres .'.']);
    }

    public function show($id)
    {
        $n_id = substr($id, 1);

        $vuser = DB::table('usuario')
            ->where('codUsuario', '=', $n_id)
            ->first();
        if (isset($vuser->estado)) {
            if ($vuser->estado == 'ACTIVO') {
                $estado = "INACTIVO";
            } else {
                $estado = "ACTIVO";
            }
        }

        $usuario = User::findOrFail($n_id);
        $usuario->estado = $estado;
        $usuario->update();
        return Redirect::to('acceso/usuario');
    }

    public function reportPdf($id)
    {
        $mytime = Carbon::now('America/Lima');
        $fecha_hora = $mytime->toDateTimeString();

        if ($id == 'TODO') {
            $id = '';
        }

        if (auth()->user()->tipo == 'SECRETARIA') {
            $usuario = DB::table('usuario as u')
                ->join('consultorio as c', 'u.codConsultorio', '=', 'c.codConsultorio')
                ->where('tipo', '=', 'DOCTOR')
                ->Where(function ($q)  use ($id) {
                    $q->orWhere('nombres', 'LIKE', '%' . $id . '%')
                        ->orWhere('numDocumento', 'LIKE', '%' . $id . '%')
                        ->orWhere('estado', 'LIKE', '%' . $id . '%')
                        ->orWhere('direccion', 'LIKE', '%' . $id . '%')
                        ->orWhere('email', 'LIKE', '%' . $id . '%')
                        ->orWhere('telefono', 'LIKE', '%' . $id . '%')
                        ->orWhere('nomConsul', 'LIKE', '%' . $id . '%');
                })
                ->paginate(10);
        } else {
            $usuario = DB::table('usuario as u')
                ->join('consultorio as c', 'u.codConsultorio', '=', 'c.codConsultorio')
                ->orWhere('nombres', 'LIKE', '%' . $id . '%')
                ->orWhere('numDocumento', 'LIKE', '%' . $id . '%')
                ->orWhere('estado', 'LIKE', '%' . $id . '%')
                ->orWhere('direccion', 'LIKE', '%' . $id . '%')
                ->orWhere('email', 'LIKE', '%' . $id . '%')
                ->orWhere('telefono', 'LIKE', '%' . $id . '%')
                ->orWhere('tipo', 'LIKE', '%' . $id . '%')
                ->orWhere('nomConsul', 'LIKE', '%' . $id . '%')
                ->paginate(10);
        }

        $empresa = DB::table('empresa')->first();

        $pdf = \PDF::loadView('acceso/usuario.report', [
            "usuario" => $usuario, "fecha_hora" => $fecha_hora,
            "id" => $id, "empresa" => $empresa
        ]);
        // ->setPaper('a4', 'landscape');
        return $pdf->stream();
    }

    public function destroy(Request $request, $id)
    {
        try {
            if ($request->ajax()) {
                $docu   = User::findOrFail($id);
                if ($docu->delete()) {
                    return response()->json([
                        'success' => true,
                        'message' => '¡Satisfactorio!, Registro eliminado con éxito.',
                    ]);
                } else {
                    return response()->json([
                        'success' => false,
                        'message' => '¡Error!, No se pudo eliminar.',
                    ]);
                }
            }
        } catch (\Exception $e) {
            if ($request->ajax()) {
                return response()->json([
                    'success' => false,
                    'message' => '¡Error!, Este registro tiene enlazado uno o mas registros.',
                ]);
            }
        }
    }

}
